package net.sf.doolin.template.support;

import net.sf.doolin.template.TemplateEngine;
import net.sf.doolin.template.velocity.VelocityTemplateEngine;

/**
 * Default template manager implementation.
 * 
 * By default, only the velocity engine is registered. Other can be added
 * declaratively by merging with the initial list:
 * 
 * <pre>
 *  &lt;bean
 *  		id=&quot;net.sf.doolin.template.TemplateManager&quot;
 *  		class=&quot;net.sf.doolin.template.support.DefaultTemplateManager&quot;&gt;
 *  		&lt;property name=&quot;engines&quot;&gt;
 *  			&lt;map merge=&quot;true&quot;&gt;
 *  				&lt;entry key=&quot;myEngineName&quot;&gt;
 *  					&lt;bean class=&quot;my.Engine&quot;/&gt;
 *  				&lt;/entry&gt;
 *  			&lt;/map&gt;
 *  		&lt;/property&gt;
 *  &lt;/bean&gt;
 * </pre>
 * 
 * @author Damien Coraboeuf
 */
public class DefaultTemplateManager extends AbstractTemplateManager {

	/**
	 * Default list of engines.
	 * 
	 * By default, only the velocity engine is registered.
	 */
	public DefaultTemplateManager() {
		// Default engines
		registerEngine(TemplateEngine.VELOCITY, new VelocityTemplateEngine());
	}

}
