package net.sf.doolin.template.velocity;

import net.sf.doolin.template.TemplateMessages;
import net.sf.doolin.template.support.AbstractTemplate;
import net.sf.jstring.LocalizableException;
import org.apache.velocity.Template;
import org.apache.velocity.VelocityContext;

import java.io.Writer;
import java.util.Map;

/**
 * Velocity template
 * 
 * @author Damien Coraboeuf
 */
public class VelocityTemplate extends AbstractTemplate {
	/**
	 * Associated template
	 */
	private Template velocityTemplate;

	/**
	 * Constructor
	 * 
	 * @param aTemplate
	 *            Velocity template which is encapsulated
	 */
	public VelocityTemplate(Template aTemplate) {
		this.velocityTemplate = aTemplate;
	}

	/**
	 * @see VelocityContext
	 * @see Template#merge(org.apache.velocity.context.Context, Writer)
	 * @see net.sf.doolin.template.Template#generate(Writer, Map)
	 */
	public void generate(Writer writer, Map<String, Object> context) {
		// Velocity Context
		VelocityContext velocityContext = new VelocityContext();
		// Add parameters
		if (context != null) {
			for (Map.Entry<String, Object> entry : context.entrySet()) {
				String name = entry.getKey();
				Object value = entry.getValue();
				velocityContext.put(name, value);
			}
		}
		// Add the Velocity tools
		velocityContext.put("tools", new VelocityTools());

		try {
			// Get the template
			this.velocityTemplate.merge(velocityContext, writer);
		} catch (LocalizableException ex) {
			throw ex;
		} catch (Exception ex) {
			throw new LocalizableException(TemplateMessages.CANNOT_GENERATE_TEMPLATE,
					ex, ex);
		}
	}

}
