package net.sf.doolin.template.velocity;

import net.sf.doolin.template.TemplateMessages;
import net.sf.doolin.template.support.AbstractTemplateEngine;
import net.sf.doolin.util.IOUtils;
import net.sf.jstring.LocalizableException;
import org.apache.velocity.Template;
import org.apache.velocity.app.Velocity;

import java.util.Properties;

/**
 * Template engine for Velocity
 * 
 * @author Damien Coraboeuf
 */
public class VelocityTemplateEngine extends AbstractTemplateEngine {

	/**
	 * Loads the resource as a Velocity template.
	 * 
	 * @see net.sf.doolin.template.TemplateEngine#getTemplate(java.lang.String)
	 */
	public net.sf.doolin.template.Template getTemplate(String resourcePath) {
		try {
			Template velocityTemplate = Velocity.getTemplate(resourcePath,
					"UTF-8");
			return new VelocityTemplate(velocityTemplate);
		} catch (LocalizableException ex) {
			throw ex;
		} catch (Exception ex) {
			throw new LocalizableException(TemplateMessages.CANNOT_CREATE_TEMPLATE,
					ex, "velocity", resourcePath, ex);
		}
	}

	/**
	 * Initialization
	 */
	public void init() {
		try {
			Properties properties = IOUtils
					.readProperties("/net/sf/doolin/template/velocity/Velocity.properties");
			// Initialization
			Velocity.init(properties);
		} catch (Exception ex) {
			throw new LocalizableException(TemplateMessages.CANNOT_INITIALIZE_ENGINE,
					ex, "Velocity", ex);
		}
	}

}
