/*
 * Created on 20 avr. 2005
 */
package net.sf.doolin.template.velocity;

import net.sf.jstring.JStrings;
import org.apache.commons.lang.StringEscapeUtils;
import org.apache.commons.lang.StringUtils;

import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * Some tools for the template
 * 
 * @author Damien Coraboeuf
 */
public class VelocityTools {
	/**
	 * Format a date using the specified format
	 * 
	 * @param date
	 *            Date to format
	 * @param format
	 *            Format to use
	 * @return Formatted date
	 */
	public String dateFormat(Date date, String format) {
		return new SimpleDateFormat(format).format(date);
	}

	/**
	 * Escape a string for XML
	 * 
	 * @param value
	 *            Value to escape
	 * @return Escaped value
	 * @see StringEscapeUtils#escapeXml(String)
	 */
	public String escapeXML(String value) {
		if (StringUtils.isBlank(value)) {
			return "";
		} else {
			return StringEscapeUtils.escapeXml(value);
		}
	}

	/**
	 * Translates a string code to a full text.
	 * 
	 * @param code
	 *            String code
	 * @return Corresponding text
	 * @see JStrings#get(java.util.Locale, String, Object...)
	 */
	public String getString(String code) {
		return JStrings.get(null, code);
	}

	/**
	 * Escape Java string to HTML. All carriage returns are replaced by
	 * <code>&lt;br/&gt;</code>.
	 * 
	 * @param value
	 *            Java string
	 * @return Escaped HTML string
	 * @see StringEscapeUtils#escapeHtml(String)
	 */
	public String translateJavaToHTML(String value) {
		if (value == null) {
			return "";
		}
		// Escape HTML
		value = StringEscapeUtils.escapeHtml(value);
		// Transforms each carriage return to <br>
		value = StringUtils.replace(value, "\n", "<br>");
		// Ok
		return value;
	}

}
